=======
CHANGES
=======


1.0.1 (2019-05-30)
------------------

- Fix package description.


1.0.0 (2019-05-30)
------------------

- Immutable Types, Immutable Dict, Immutable Set, Immutable List

- Revisioned Immutable with Revision Manager sample implementation

- Optional: pjpersist support for immutables. Requires pjpersist>=1.7.0.

- Initial Release
